
From: "Antonino A. Daplas" <adaplas@gmail.com>

Update feature-list-2.6.txt about the framebuffer layer.  Adds what user needs
to know to get a working framebuffer console in 2.6, major differences between
2.4 and 2.6, and some features added to the layer that were not present in
2.4.

Signed-off-by: Antonino Daplas <adaplas@pol.net>
Cc: Dave Jones <davej@codemonkey.org.uk>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 Documentation/feature-list-2.6.txt |   30 +++++++++++++++++++++++++-----
 1 files changed, 25 insertions(+), 5 deletions(-)

diff -puN Documentation/feature-list-2.6.txt~fbdev-update-framebuffer-feature-list Documentation/feature-list-2.6.txt
--- devel/Documentation/feature-list-2.6.txt~fbdev-update-framebuffer-feature-list	2005-08-21 21:54:09.000000000 -0700
+++ devel-akpm/Documentation/feature-list-2.6.txt	2005-08-21 21:54:09.000000000 -0700
@@ -481,6 +481,17 @@ procps.
 
 Framebuffer layer.
 ~~~~~~~~~~~~~~~~~~
+- GOTCHAS
+  - Just enabling CONFIG_FRAMEBUFFER is not enough to enable a framebuffer
+    console.  CONFIG_FRAMEBUFFER_CONSOLE needs to be set. If
+    CONFIG_FRAMEBUFFER_CONSOLE=m, you need to do a 'modprobe fbcon' to get
+    a framebuffer console.
+  - "stty rows r cols c" may behave differently compared to 2.4.  Where stty
+    just changes the window size without changing the video mode in 2.4, in
+    2.6, stty may also change the video mode, depending on the driver.
+  - initialization sequence for multiple framebuffers is fixed in 2.6. But
+    one can choose which driver gets mapped to the console using the boot
+    option "fbcon:map:n"
 - James Simmons has reworked the framebuffer/console layer considerably for
   2.6. Support for some cards is still lagging a little, but it should be
   functionally no different than previous incarnations.
@@ -489,15 +500,22 @@ Framebuffer layer.
     append = "video=radeon:1024x768-24@100"
   needs to become..
     append = "video=radeonfb:1024x768-24@100"
-- Current userspace tools (fbset for eg) are not yet updated,
-  and won't function as expected.
-- The VESA framebuffer now enables MTRRs for the framebuffer memory range during
-  initialisation (Note: PCI cards only).
-  If you notice screen corruption, please report this, along with an lspci output,
-  so your card can be blacklisted.
+- Current userspace tools (fbset for eg) need not be updated, but prior to
+  kernels older than linux-2.6.8, they won't function as expected.
+- The VESA framebuffer now enables MTRRs for the framebuffer memory range
+  during initialisation (Note: PCI cards only).
+  If you notice screen corruption, please report this, along with an lspci
+  output, so your card can be blacklisted.
+- Support for parsing the EDID (aka Plug and Play Displays) are available
+  for several drivers. If this feature is available, the driver can
+  automatically detect the best mode for your display.
+- There are now three ways to change the video mode.  The first is by using the
+  venerable fbset. It is the most powerful and the one recommended for main
+  use. The second is by sysfs and the third is by stty, as mentioned above.
+  Note that using sysfs or stty is dependent on the number of video modes
+  currently supported internally by the driver.
 - Any problems should go to <jsimmons@infradead.org>
 
-
 IDE.
 ~~~~
 - The IDE code rewrite was subject to much criticism in early 2.5.x, which
_
